==> codingfuture-cffirehol-0.9.0.tar.gz: codingfuture-cffirehol-0.9.0/lib/puppet/provider/cffirehol_config/firehol.rb <==

Puppet::Type.type(:cffirehol_config).provide(
    :firehol,
    :parent => Puppet::Type.type(:cfnetwork_firewall_port).provider(:firehol)
) do
    desc "FireHOL provider for cffirehol_config"
    
    commands :firehol => "/sbin/firehol"
    
    def self.instances
        instances = []
        fhmeta = cf_firehol().read_config()
        type = getMetaIndex()
            
        instances << self.new(
            :name => 'firehol',
            :ensure => fhmeta['version'].empty? ? :absent : :exists,
            :custom_headers => fhmeta['custom_headers'],
            :ip_whitelist => fhmeta['ip_whitelist'],
            :ip_blacklist => fhmeta['ip_blacklist'],
            :synproxy_public => fhmeta['synproxy_public'],
        )
        
        debug('Instances:' + instances.to_s)
        instances
    end
    
    def flush
        debug('flush')
        ensure_val = @property_hash[:ensure]
            
        case ensure_val 
        when :absent
            write_config('custom_headers', [])
            write_config('ip_whitelist', [])
            write_config('ip_blacklist', [])
            write_config('synproxy_public', false)
        when :present, :exists
            write_config('custom_headers', (@resource[:custom_headers] or []))
            write_config('ip_whitelist', (@resource[:ip_whitelist] or []))
            write_config('ip_blacklist', (@resource[:ip_blacklist] or []))
            write_config('synproxy_public', (@resource[:synproxy_public] or false))
        else
            warning(@resource)
            warning(@property_hash)
            raise Puppet::DevError, "Unknown 'ensure' = " + ensure_val.to_s
        end

        cf_firehol = self.class.cf_firehol()
        reconf = cf_firehol.gen_config()
        cf_firehol.reset_config()
        
        if reconf and @resource[:enable]
            debug('Running firehol')
            firehol('start')
        end
    end
end

==> codingfuture-cffirehol-0.9.11.tar.gz: codingfuture-cffirehol-0.9.11/lib/puppet/provider/cffirehol_config/firehol.rb <==

require 'fileutils'

# Done this way due to some weird behavior in tests also ignoring $LOAD_PATH
require File.expand_path( '../../../../cffirehol/providerbase', __FILE__ )

Puppet::Type.type(:cffirehol_config).provide(
    :firehol,
    :parent => CfFirehol::ProviderBase
) do
    desc "FireHOL provider for cffirehol_config"
    
    commands :firehol => "/sbin/firehol"
    
    def self.instances
        instances = []
        fhmeta = cf_firehol().read_config()
        type = getMetaIndex()
            
        instances << self.new(
            :name => 'firehol',
            :ensure => fhmeta['generator_version'].empty? ? :absent : :exists,
            :custom_headers => fhmeta['custom_headers'],
            :ip_whitelist => fhmeta['ip_whitelist'],
            :ip_blacklist => fhmeta['ip_blacklist'],
            :synproxy_public => fhmeta['synproxy_public'],
            :persistent_dhcp => fhmeta['persistent_dhcp'],
            :enable => fhmeta['enable'],
        )
        
        debug('Instances:' + instances.to_s)
        instances
    end
    
    def flush
        debug('flush')
        ensure_val = @property_hash[:ensure]
            
        case ensure_val 
        when :absent
            write_config('custom_headers', [])
            write_config('ip_whitelist', [])
            write_config('ip_blacklist', [])
            write_config('synproxy_public', false)
            write_config('persistent_dhcp', false)
            write_config('enable', false)
        when :present, :exists
            write_config('custom_headers', (@resource[:custom_headers] or []))
            write_config('ip_whitelist', (@resource[:ip_whitelist] or []))
            write_config('ip_blacklist', (@resource[:ip_blacklist] or []))
            write_config('synproxy_public', (@resource[:synproxy_public] or false))
            write_config('persistent_dhcp', (@resource[:persistent_dhcp] or false))
            write_config('enable', (@resource[:enable] or false))
        else
            warning(@resource)
            warning(@property_hash)
            raise Puppet::DevError, "Unknown 'ensure' = " + ensure_val.to_s
        end

        cf_firehol = self.class.cf_firehol()
        reconf = cf_firehol.gen_config()
        cf_firehol.reset_config()
        
        restart_file = CfFirehol::FIREHOL_START_REQUIRED_FILE
        reconf ||= File.exists? restart_file
        
        if reconf
            FileUtils.touch(restart_file)
            
            if @resource[:enable]
                warning('Running: /sbin/firehol start')
                firehol('start')
                FileUtils.rm_f(restart_file)
            end
        end
    end
    
    def self.getMetaIndex
        nil
    end
end
